==> aws_prototyping_sdk.open_api_gateway-0.2.2.tar.gz: package/lib/project/codegen/generate.d.ts <==
import { Project } from "projen";
import { ClientLanguage } from "../languages";
import { GeneratedPythonClientProjectOptions } from "./generated-python-client";
import { GeneratedTypescriptClientProjectOptions } from "./generated-typescript-client-project";
declare type CommonProjectOptions = "specPath" | "name" | "outdir" | "moduleName";
/**
 * Options for generating clients
 */
export interface GenerateClientProjectsOptions {
    /**
     * The parent project for the generated clients
     */
    readonly parent?: Project;
    /**
     * Whether or not the root api project has a parent (ie whether or not we are in a monorepo)
     */
    readonly rootProjectHasParent: boolean;
    /**
     * The name of the api package, used to infer client names unless overrides are specified
     */
    readonly parentPackageName: string;
    /**
     * The directory in which to generate code for all clients
     */
    readonly generatedCodeDir: string;
    /**
     * Path to the parsed spec file
     * We use the parsed spec such that refs are resolved to support multi-file specs
     */
    readonly parsedSpecPath: string;
    /**
     * Options for the typescript client project.
     * These will override any inferred properties (such as the package name).
     */
    readonly typescriptOptions: Omit<GeneratedTypescriptClientProjectOptions, CommonProjectOptions>;
    /**
     * Options for the python client project
     * These will override any inferred properties (such as the package name).
     */
    readonly pythonOptions: Omit<GeneratedPythonClientProjectOptions, CommonProjectOptions>;
}
/**
 * Generate API clients in the given languages
 * @param languages the languages to generate clients for
 * @param options options for the projects to be created
 */
export declare const generateClientProjects: (languages: Set<ClientLanguage>, options: GenerateClientProjectsOptions) => {
    [language: string]: Project;
};
export {};

==> aws_prototyping_sdk.open_api_gateway-0.2.10.tar.gz: package/lib/project/codegen/generate.d.ts <==
import { Project } from "projen";
import { ClientLanguage } from "../languages";
import { GeneratedJavaClientProjectOptions } from "./generated-java-client-project";
import { GeneratedPythonClientProjectOptions } from "./generated-python-client-project";
import { GeneratedTypescriptClientProjectOptions } from "./generated-typescript-client-project";
declare type CommonProjectOptions = "specPath" | "name" | "outdir" | "moduleName" | "artifactId" | "groupId";
/**
 * Options for generating clients
 */
export interface GenerateClientProjectsOptions {
    /**
     * The parent project for the generated clients
     */
    readonly parent?: Project;
    /**
     * Whether or not the root api project has a parent (ie whether or not we are in a monorepo)
     */
    readonly rootProjectHasParent: boolean;
    /**
     * The name of the api package, used to infer client names unless overrides are specified
     */
    readonly parentPackageName: string;
    /**
     * The directory in which to generate code for all clients
     */
    readonly generatedCodeDir: string;
    /**
     * Path to the parsed spec file
     * We use the parsed spec such that refs are resolved to support multi-file specs
     */
    readonly parsedSpecPath: string;
    /**
     * Options for the typescript client project.
     * These will override any inferred properties (such as the package name).
     */
    readonly typescriptOptions: Omit<GeneratedTypescriptClientProjectOptions, CommonProjectOptions>;
    /**
     * Options for the python client project
     * These will override any inferred properties (such as the package name).
     */
    readonly pythonOptions: Omit<GeneratedPythonClientProjectOptions, CommonProjectOptions>;
    /**
     * Options for the java client project
     * These will override any inferred properties (such as the package name).
     */
    readonly javaOptions: Omit<GeneratedJavaClientProjectOptions, CommonProjectOptions>;
}
/**
 * Generate API clients in the given languages
 * @param languages the languages to generate clients for
 * @param options options for the projects to be created
 */
export declare const generateClientProjects: (languages: Set<ClientLanguage>, options: GenerateClientProjectsOptions) => {
    [language: string]: Project;
};
export {};
